summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/objecttreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/objecttreeview.h')
-rw-r--r--kexi/formeditor/objecttreeview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/formeditor/objecttreeview.h b/kexi/formeditor/objecttreeview.h
index 46266144..b625c0ad 100644
--- a/kexi/formeditor/objecttreeview.h
+++ b/kexi/formeditor/objecttreeview.h
@@ -31,7 +31,7 @@ class Form;
class KFORMEDITOR_EXPORT ObjectTreeViewItem : public KListViewItem
{
public:
- ObjectTreeViewItem(ObjectTreeViewItem *tqparent, ObjectTreeItem *item);
+ ObjectTreeViewItem(ObjectTreeViewItem *parent, ObjectTreeItem *item);
ObjectTreeViewItem(KListView *list, ObjectTreeItem *item=0);
virtual ~ObjectTreeViewItem();
@@ -70,7 +70,7 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
TQ_OBJECT
public:
- ObjectTreeView(TQWidget *tqparent=0, const char *name=0, bool tabStop = false);
+ ObjectTreeView(TQWidget *parent=0, const char *name=0, bool tabStop = false);
virtual ~ObjectTreeView();
virtual TQSize tqsizeHint() const;
@@ -89,7 +89,7 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
It is added to current selection if \a add is true. */
void setSelectedWidget(TQWidget *w, bool add=false);
/*! Adds the ObjectTreeItem \a item in the list, with the appropriate tqparent. */
void addItem(ObjectTreeItem *item);
/*! Removess the ObjectTreeItem \a item from the list. */
@@ -113,7 +113,7 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
protected:
//! Internal function to fill the list.
- ObjectTreeViewItem* loadTree(ObjectTreeItem *item, ObjectTreeViewItem *tqparent);
+ ObjectTreeViewItem* loadTree(ObjectTreeItem *item, ObjectTreeViewItem *parent);
//! \return The item whose name is \a name.
ObjectTreeViewItem* findItem(const TQString &name);
@@ -89,7 +89,7 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
It is added to current selection if \a add is true. */
void setSelectedWidget(TQWidget *w, bool add=false);
- /*! Adds the ObjectTreeItem \a item in the list, with the appropriate tqparent. */
+ /*! Adds the ObjectTreeItem \a item in the list, with the appropriate parent. */
void addItem(ObjectTreeItem *item);
/*! Removess the ObjectTreeItem \a item from the list. */